***********************************************
********************** US ****************
***********************************************

use aid_terror, clear

****************************************
**************** Table 1****************
****************************************

sum dep lus_aid luk_aid lfr_aid lgr_aid lus_gov luk_gov lfr_gov lgr_gov	leus_aid leuk_aid lefr_aid legr_aid ideal_us ideal_uk ideal_fr ideal_gr shr_trans diversity lpop lgdppc lmil

preserve 

sort gid year

* Generate time variables
by gid: gen duration=[_n]
gen t = duration
gen t2 = t^2

* Defince Global variables
global indep lgdppc lpop lmil shr_trans diversity
global indep_us leus_aid ideal_us

****************************************
**************** Table 2****************
****************************************
* store mean value of US Aid
sum lus_aid if lus_aid > 0
local m_us = r(mean)

*** 1. OLS
eststo n1: reg dep lus_aid t t2 $indep_us $indep, vce(cluster ccode)

*** 2. Linear 2SLS
eststo n2: ivregress 2sls dep t t2 $indep_us $indep (lus_aid=lus_gov), vce(cluster ccode)
ivregress 2sls dep t t2 $indep_us $indep (lus_aid=lus_gov), vce(cluster ccode) first
estat firststage

*** 3 . Logit Control Function
capture program drop logit_cf
program define logit_cf
	
	reg lus_aid lus_gov t t2 $indep_us $indep, vce(cluster ccode)
	predict lus_aid_res, residual
	
	logit dep lus_aid lus_aid_res t t2 $indep_us $indep, vce(cluster gid)
	drop lus_aid_res
end

eststo n3: bootstrap, reps(1050)  seed(12345) cluster(gid): logit_cf

estout n1 n2 n3, cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N chi2, star(chi2) fmt(%9.0g %9.3f)) 

*** 4. odd ratios			
estout n3, eform cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N chi2, star(chi2) fmt(%9.0g %9.3f))		


***********************************************************		
** The beginning of calculating the counterfactual duration
************************************************************

reg lus_aid lus_gov t t2 $indep_us $indep, vce(cluster ccode)
predict lus_aid_res, residual

logit dep lus_aid lus_aid_res t t2 $indep_us $indep, vce(cluster gid)
predict pr if e(sample), pr
keep if e(sample)

** Get the aggregate aid effects in terms of odds ratios
margins, expression(exp(_b[lus_aid]+_b[leus_aid]))

** Calculate average survivng duration on observed samples
by gid: gen k = 1 if t == [_N]
su t if lus_aid > 0 & k == 1

** Add two hypothetical groups with average characteristics in the two counterfactual groups
sum t
local t_max = r(max)
local n_old = _N
local n_new = _N + `t_max'*2
local n_g1 = _N + `t_max'
set obs `n_new'

** Allocate gid number 
replace gid=100000 if gid == . & _n <= `n_g1'
replace gid=100001 if gid == . 

** Define global variables
global indep_hyp lgdppc lpop lmil shr_trans diversity leus_aid ideal_us

forvalues idnum = 100000(1)100001 { 
  replace t = (_n - `n_old') if gid == 100000
  replace t = (_n - `t_max' - `n_old') if gid == 100001
  replace duration = t if gid == `idnum'
  replace t2 = t*t if gid == `idnum'
}
** fill in the avg charactersitics 
foreach x in $indep_hyp lus_aid_res {
   quietly sum `x'
   replace `x' = r(mean) if gid == 100000 | gid == 100001
}
** Define the two counterfactual values for aid
local counterfactual0 = 0
local counterfactual1 = `m_us' 

replace lus_aid = `counterfactual0' if gid == 100000
replace lus_aid = `counterfactual1' if gid == 100001
predict prob, pr

** Get the hazard probability at each period
keep if gid >= 100000
keep prob t gid
reshape wide prob, i(t) j(gid)
ren prob100000 h0 
ren prob100001 h1 
gen prob_diff = h1 - h0
list
sum 

**Figure 1
twoway (connected h0 t if t <=20) (connected h1 t if t <=20), ///
		legend(order(1 "ln(US aid) = 0" 2 "Mean if US Aids > 0")) scheme(s1mono)

** get the cumulative failure and survive probability		
gen one_h0 = 1 - h0 
gen one_h1 = 1 - h1
sort t

gen s0 = 1-h0 in 1
gen s1 = 1-h1 in 1

replace s0 = s0[_n-1]*(1-h0) in 2/`t_max' 
replace s1 = s1[_n-1]*(1-h1) in 2/`t_max' 

gen f0 = 1-s0 in 1
gen f1 = 1-s1 in 1

replace f0 = s0[_n-1]-s0[_n] in 2/`t_max' 
replace f1 = s1[_n-1]-s1[_n] in 2/`t_max' 


gen f0_sum=sum(f0) 
gen f1_sum=sum(f1) 

replace f0 = 1 - f0_sum in `t_max' 
replace f1 = 1 - f1_sum in `t_max' 

** Calculate average surviving time
gen life0 = t*f0
sum life0
local lif0 = r(sum) 

gen life1 = t*f1
sum life1
local lif1 = r(sum) 

****************************************
**************** Table 6 ****************
****************************************
local life_dif = `lif1' - `lif0' 
display `lif0'
display `lif1'
display `life_dif'

restore	
