use aid_terror, clear

* Defince Global variables
global indep lgdppc lpop lmil shr_trans diversity
global indep_us leus_aid ideal_us
global indep_uk leuk_aid ideal_uk
global indep_fr lefr_aid ideal_fr
global indep_gr legr_aid ideal_gr

eststo clear

********************
*********US********
*******************
preserve 

sort gid year

* Generate time variables
by gid: gen duration=[_n]
gen t = duration
gen t2 = t^2

*** Logit Control Function
capture program drop logit_cf
program define logit_cf
	
	reg lus_aid lus_inv1 t t2 $indep_us $indep, vce(cluster ccode)
	predict lus_aid_res, residual
	
	logit dep lus_aid lus_aid_res t t2 $indep_us $indep, vce(cluster gid)
	drop lus_aid_res
end

eststo n1: bootstrap, reps(1050)  seed(12345) cluster(gid) : logit_cf

estout n1, eform cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N chi2, star(chi2) fmt(%9.0g %9.3f)) 

***Aggregate effect and F-statistics on instrument variable
reg lus_aid lus_inv1 t t2 $indep_us $indep, vce(cluster ccode)
test lus_inv1
predict lus_aid_res, residual
	
logit dep lus_aid lus_aid_res t t2 $indep_us $indep, vce(cluster gid)
predict pr if e(sample), pr
keep if e(sample)

margins, expression(exp(_b[lus_aid]+_b[leus_aid]))

restore


********************
**********UK*******
********************
preserve

sort gid year

drop if year < 1992 // UK aid starts from 1992

* Generate time variables
by gid: gen duration=[_n]
gen t = duration
gen t2 = t^2

*** Logit Control Function
capture program drop logit_cf
program define logit_cf
	
	reg luk_aid luk_inv1 t t2 $indep_uk $indep, vce(cluster ccode)
	predict luk_aid_res, residual
	
	logit dep luk_aid luk_aid_res t t2 $indep_uk $indep, vce(cluster gid)
	drop luk_aid_res
end

eststo n2: bootstrap, reps(1050)  seed(12345) cluster(gid) : logit_cf

estout n2, eform cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N chi2, star(chi2) fmt(%9.0g %9.3f)) 

***Aggregate effect and F-statistics on instrument variable
reg luk_aid luk_inv1 t t2 $indep_uk $indep, vce(cluster ccode)
test luk_inv1
predict luk_aid_res, residual
	
logit dep luk_aid luk_aid_res t t2 $indep_uk $indep, vce(cluster gid)
predict pr if e(sample), pr
keep if e(sample)

margins, expression(exp(_b[luk_aid]+_b[leuk_aid]))

restore


********************
******France********
********************

preserve 
sort gid year
eststo clear

* Generate time variables
by gid: gen duration=[_n]
gen t = duration
gen t2 = t^2

*** Logit Control Function
capture program drop logit_cf
program define logit_cf
	
	reg lfr_aid lfr_inv1 t t2 $indep_fr $indep, vce(cluster ccode)
	predict lfr_aid_res, residual
	
	logit dep lfr_aid lfr_aid_res t t2 $indep_fr $indep, vce(cluster gid)
	drop lfr_aid_res
end

eststo n3: bootstrap, reps(1050)  seed(12345) cluster(gid) : logit_cf

estout n3, eform cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N chi2, star(chi2) fmt(%9.0g %9.3f)) 

***Aggregate effect and F-statistics on instrument variable
reg lfr_aid lfr_inv1 t t2 $indep_fr $indep, vce(cluster ccode)
test lfr_inv1
predict lfr_aid_res, residual
	
logit dep lfr_aid lfr_aid_res t t2 $indep_fr $indep, vce(cluster gid)
predict pr if e(sample), pr
keep if e(sample)

margins, expression(exp(_b[lfr_aid]+_b[lefr_aid]))

restore


********************
******Germany*******
********************
preserve 
sort gid year

drop if year < 1999 // Germany aid starts from 1999

* Generate time variables
by gid: gen duration=[_n]
gen t = duration
gen t2 = t^2

*** Logit Control Function
capture program drop logit_cf
program define logit_cf
	
	reg lgr_aid lgr_inv1 t t2 $indep_gr $indep, vce(cluster ccode)
	predict lgr_aid_res, residual
	
	logit dep lgr_aid lgr_aid_res t t2 $indep_gr $indep, vce(cluster gid)
	drop lgr_aid_res
end

eststo n4: bootstrap, reps(1100)  seed(12345) cluster(gid) : logit_cf

estout n4, eform cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N chi2, star(chi2) fmt(%9.0g %9.3f)) 

***Aggregate effect and F-statistics on instrument variable
reg lgr_aid lgr_inv1 t t2 $indep_gr $indep, vce(cluster ccode)
test lgr_inv1
predict lgr_aid_res, residual
	
logit dep lgr_aid lgr_aid_res t t2 $indep_gr $indep, vce(cluster gid)
predict pr if e(sample), pr
keep if e(sample)

margins, expression(exp(_b[lgr_aid]+_b[legr_aid]))

restore

